<?php
class Clockwork_FSCF_Plugin extends Clockwork_Plugin {
  
  protected $plugin_name = 'FS Contact Form';
  protected $language_string = 'fscf_sms';
  protected $prefix = 'clockwork_fscf';
  protected $folder = '';
  
  /**
   * Constructor: setup callbacks and plugin-specific options
   *
   * @author James Inman
   */
  public function __construct() {
    parent::__construct();
    
    // Set the plugin's Clockwork SMS menu to load the contact forms
    $this->plugin_callback = array( $this, 'fscf' );
    $this->plugin_dir = basename( dirname( __FILE__ ) );
    
    // Setup callbacks for this plugin
		add_action( 'fsctf_mail_sent', array( &$this, 'send_sms' ) );   
  }
  
  /**
  * Register settings for this plugin
  *
  * @return void
  * @author James Inman
   */
  public function setup_admin_init() {
    parent::setup_admin_init();

    register_setting( 'fscf_sms', 'fscf_sms', array( $this, 'fscf_sms_options_validate' ) );
    add_settings_section( 'fscf_sms', 'General Settings', array( $this, 'fscf_general_settings_text' ), 'fscf_sms' );
    add_settings_field( 'fscf_mobile_number', 'Mobile Number', array( $this, 'fscf_mobile_number_input' ), 'fscf_sms', 'fscf_sms' );
  }
  
  /**
   * Setup the admin navigation
   *
   * @return void
   * @author James Inman
   */
  public function setup_admin_navigation() {
    parent::setup_admin_navigation();
  }
  
  /**
   * Setup HTML for the admin <head>
   *
   * @return void
   * @author James Inman
   */
  public function setup_admin_head() {
    echo '<link rel="stylesheet" type="text/css" href="' . plugins_url( 'css/clockwork.css', __FILE__ ) . '">';
  }
  
  /**
   * Empty function to provide a callback for the main plugin action page
   *
   * @return void
   * @author James Inman
   */
  public function fscf() {
    $this->render_template( 'form-options' );
  }

  /**
   * Send SMS on contact form submission
   *
   * @param object $form Contact form to send  
   * @return void
   * @author James Inman
   */
  public function send_sms( $form ) {
    $options = array_merge( get_option( 'clockwork_options' ), get_option( 'fscf_sms' ) );
    if( isset( $options['api_key'] ) && isset( $options['mobile'] ) && $options['mobile'] != '' ) { 
      
      // Put name in message if it's available
      if( $form->posted_data != null && $form->posted_data['from_name'] != null && trim( $form->posted_data['from_name'] ) != '' ) {
      	$name = trim( $form->posted_data['from_name'] );
      } else {
      	$name = 'Somebody';
      }

    	$message = $name . ' filled in your contact form on ' . get_bloginfo( 'name' ) . '.';
    	$mobile = explode( ',', $options['mobile'] );
    
      try {
        $clockwork = new WordPressClockwork( $options['api_key'] );
        $messages = array();
        foreach( $mobile as $to ) {
          $messages[] = array( 'from' => $options['from'], 'to' => $to, 'message' => $message );          
        }
        $result = $clockwork->send( $messages );
      } catch( ClockworkException $e ) {
        $result = "Error: " . $e->getMessage();
      } catch( Exception $e ) { 
        $result = "Error: " . $e->getMessage();
      }
    }
  }
  
  /**
   * Introductory text for the form
   *
   * @return void
   * @author James Inman
   */
  public function fscf_general_settings_text() {
    echo '<p>Enter the mobile number text messages are sent to when your contact form is submitted.</p>';
	}
  
  /**
   * Input box for the mobile number
   *
   * @return void
   * @author James Inman
   */
  public function fscf_mobile_number_input() {
    $options = get_option( 'fscf_sms' );
    if( isset( $options['mobile'] ) ) {
      echo "<input id='clockwork_api_key' name='fscf_sms[mobile]' size='40' type='text' value='" . $options['mobile'] . "' />";
    } else {
      echo "<input id='clockwork_api_key' name='fscf_sms[mobile]' size='40' type='text' value='' />";      
    }
		echo ' <p class="description">' . __('International format, starting with a country code e.g. 447123456789', 'fscf_sms') . '</p>';
  }
  
  /**
   * Remove leading +s and 00s from the mobile number
   *
   * @return void
   * @author James Inman
   */
  public function fscf_sms_options_validate( $val ) {
    $val['mobile'] = trim( $val['mobile'] );
    $val['mobile'] = preg_replace( '/^([0]{2}|[\+])/', '', $val['mobile'] );
    
    if( ( strlen( $val['mobile'] ) < 9 ) || strlen( $val['mobile'] ) > 14 ) {
      add_settings_error( 'fscf_sms', 'fscf_sms', 'Please make sure you enter a mobile number in valid international format.', 'error' );
      $val['mobile'] = '';
    }
    return $val;
  }
  
  /**
   * Check if username and password have been entered
   *
   * @return void
   * @author James Inman
   */
  public function get_existing_username_and_password() {
    if( !defined( FSCF_PLUGIN_DIR ) ) {
      define( FSCF_PLUGIN_DIR, WP_PLUGIN_DIR . '/si-contact-form/' );
    }
    
    $options = get_option( 'fscf_sms' );
    if( isset( $options['username'] ) && isset( $options['password'] ) ) {
      return array( 'username' => $options['username'], 'password' => $options['password'] );
    } else {
      return false;
    }
  }
  
}

$cp = new Clockwork_FSCF_Plugin();